package com.sensor.iot.api.interceptor;

import com.github.lianjiatech.retrofit.spring.boot.interceptor.BasePathMatchInterceptor;
import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.ClientToken;
import com.sensor.iot.api.service.ClientTokenService;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import okhttp3.Request;
import okhttp3.Response;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.concurrent.TimeUnit;

/**
 * AuthInterceptor
 *
 * @author Frank
 */
@Setter
@Component
@RequiredArgsConstructor
public class AuthInterceptor extends BasePathMatchInterceptor {
    private final ClientTokenService clientTokenService;
    private final RedisTemplate<String, String> redisTemplate;

    private String clientId;

    private String clientSecret;

    @Override
    protected Response doIntercept(Chain chain) throws IOException {
        Request request = chain.request();
        Request newReq = request.newBuilder()
                .addHeader("Authorization", tokenCache())
                .build();
        return chain.proceed(newReq);
    }

    private String tokenCache() {
        String key = "client:token:" + clientId;
        String token = redisTemplate.opsForValue().get(key);
        if (token != null) {
            return token;
        }
        ApiResp<ClientToken> tokenApiResp = clientTokenService.getAuthToken(clientId, clientSecret, "client_credentials");
        token = tokenApiResp.data().getClientToken();
        redisTemplate.opsForValue().set(key, token, 7000, TimeUnit.SECONDS);
        return token;
    }
}
