package com.sensor.iot.api.service;

import com.github.lianjiatech.retrofit.spring.boot.core.RetrofitClient;
import com.sensor.iot.api.annotation.Auth;
import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.DeviceReq;
import retrofit2.http.*;

import java.util.Map;

/**
 * DeviceApiService
 *
 * @author Frank
 */
@RetrofitClient(baseUrl = "${sensor.iot.api.baseUrl}")
@Auth(clientId = "${sensor.iot.api.clientId}", clientSecret = "${sensor.iot.api.clientSecret}")
public interface DeviceApiService {

    /**
     * 创建设备信息
     *
     * @param params {@link DeviceReq}
     * @return {@link ApiResp}
     */
    @POST("/iot/api/device/add")
    ApiResp<Map<String, Object>> createDevice(@Body DeviceReq params);

    /**
     * 更新设备信息
     *
     * @param params {@link DeviceReq}
     * @return {@link ApiResp}
     */
    @PUT("/iot/api/device/edit")
    ApiResp<Map<String, Object>> updateDevice(@Body DeviceReq params);

    /**
     * 查询设备信息
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    @GET("/iot/api/device/{id}")
    ApiResp<Map<String, Object>> queryInfo(@Path("id") String deviceId);

    /**
     * 删除设备信息
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    @DELETE("/iot/api/device/{id}")
    ApiResp<Map<String, Object>> deleteDevice(@Path("id") String deviceId);
}
