package com.sensor.iot.api.service;

import com.github.lianjiatech.retrofit.spring.boot.core.RetrofitClient;
import com.sensor.iot.api.annotation.Auth;
import com.sensor.iot.api.model.*;
import retrofit2.http.Body;
import retrofit2.http.POST;
import retrofit2.http.PUT;

import java.util.Map;

/**
 * DeviceOptApiService
 *
 * @author Frank
 */
@RetrofitClient(baseUrl = "${sensor.iot.api.baseUrl}")
@Auth(clientId = "${sensor.iot.api.clientId}", clientSecret = "${sensor.iot.api.clientSecret}")
public interface DeviceOptApiService {

    /**
     * 读取设备属性
     *
     * @param params {@link ReadPropReq}
     * @return {@link ApiResp}
     */
    @POST("/iot/api/opt/device/properties")
    ApiResp<Map<String, Object>> readProperty(@Body ReadPropReq params);

    /**
     * 编辑设备属性
     *
     * @param params {@link WritePropReq}
     * @return {@link ApiResp}
     */
    @PUT("/iot/api/opt/device/properties")
    ApiResp<Map<String, Object>> writeProperty(@Body WritePropReq params);

    /**
     * 下发自定义消息
     *
     * @param params {@link SendMsgReq}
     * @return {@link ApiResp}
     */
    @POST("/iot/api/opt/device/sendMsg")
    ApiResp<Map<String, Object>> sendMsg(@Body SendMsgReq params);

    /**
     * 执行设备功能
     *
     * @param params {@link ExecFuncReq}
     * @return {@link ApiResp}
     */
    @POST("/iot/api/opt/device/function")
    ApiResp<Map<String, Object>> funcInvoke(@Body ExecFuncReq params);


}
